@@ -21,6 +21,7 @@ from .schema_utils import SchemaJSONEncoder, process_schema
 from .utils import (
     dont_throw,
     get_content,
+    merge_text_parts,
     process_content_union,
     process_stream_chunk,
     role_from_content_union,
@@ -205,15 +206,17 @@ def _set_request_attributes(span, args, kwargs):
             contents = [contents]
         for content in contents:
             processed_content = process_content_union(content)
-            content_str = get_content(processed_content)
+            content_payload = get_content(processed_content)
+            if isinstance(content_payload, dict):
+                content_payload = [content_payload]
 
             set_span_attribute(
                 span,
                 f"{gen_ai_attributes.GEN_AI_PROMPT}.{i}.content",
                 (
-                    content_str
-                    if isinstance(content_str, str)
-                    else json_dumps(content_str)
+                    content_payload
+                    if isinstance(content_payload, str)
+                    else json_dumps(content_payload)
                 ),
             )
             blocks = (
@@ -317,20 +320,22 @@ def _set_response_attributes(span, response: types.GenerateContentResponse):
         for candidate in candidates_list:
             has_content = False
             processed_content = process_content_union(candidate.content)
-            content_str = get_content(processed_content)
+            content_payload = get_content(processed_content)
+            if isinstance(content_payload, dict):
+                content_payload = [content_payload]
 
             set_span_attribute(
                 span, f"{gen_ai_attributes.GEN_AI_COMPLETION}.{i}.role", "model"
             )
-            if content_str:
+            if content_payload:
                 has_content = True
                 set_span_attribute(
                     span,
                     f"{gen_ai_attributes.GEN_AI_COMPLETION}.{i}.content",
                     (
-                        content_str
-                        if isinstance(content_str, str)
-                        else json_dumps(content_str)
+                        content_payload
+                        if isinstance(content_payload, str)
+                        else json_dumps(content_payload)
                     ),
                 )
             blocks = (
@@ -379,6 +384,10 @@ def _build_from_streaming_response(
     aggregated_usage_metadata = defaultdict(int)
     model_version = None
     for chunk in response:
+        try:
+            span.add_event("llm.content.completion.chunk")
+        except Exception:
+            pass
         # Important: do all processing in a separate sync function, that is
         # wrapped in @dont_throw. If we did it here, the @dont_throw on top of
         # this function would not be able to catch the errors, as they are
@@ -403,7 +412,7 @@ def _build_from_streaming_response(
             candidates=[
                 {
                     "content": {
-                        "parts": final_parts,
+                        "parts": merge_text_parts(final_parts),
                         "role": role,
                     },
                 }
@@ -429,6 +438,10 @@ async def _abuild_from_streaming_response(
     aggregated_usage_metadata = defaultdict(int)
     model_version = None
     async for chunk in response:
+        try:
+            span.add_event("llm.content.completion.chunk")
+        except Exception:
+            pass
         # Important: do all processing in a separate sync function, that is
         # wrapped in @dont_throw. If we did it here, the @dont_throw on top of
         # this function would not be able to catch the errors, as they are
@@ -453,7 +466,7 @@ async def _abuild_from_streaming_response(
             candidates=[
                 {
                     "content": {
-                        "parts": final_parts,
+                        "parts": merge_text_parts(final_parts),
                         "role": role,
                     },
                 }
