@@ -27,6 +27,7 @@ class Instruments(Enum):
     GOOGLE_GENAI = "google_genai"
     GROQ = "groq"
     HAYSTACK = "haystack"
+    KERNEL = "kernel"
     LANCEDB = "lancedb"
     LANGCHAIN = "langchain"
     LANGGRAPH = "langgraph"
@@ -74,6 +75,7 @@ INSTRUMENTATION_INITIALIZERS: dict[
     Instruments.GOOGLE_GENAI: initializers.GoogleGenAIInstrumentorInitializer(),
     Instruments.GROQ: initializers.GroqInstrumentorInitializer(),
     Instruments.HAYSTACK: initializers.HaystackInstrumentorInitializer(),
+    Instruments.KERNEL: initializers.KernelInstrumentorInitializer(),
     Instruments.LANCEDB: initializers.LanceDBInstrumentorInitializer(),
     Instruments.LANGCHAIN: initializers.LangchainInstrumentorInitializer(),
     Instruments.LANGGRAPH: initializers.LanggraphInstrumentorInitializer(),
@@ -105,7 +107,6 @@ def init_instrumentations(
     tracer_provider: TracerProvider,
     instruments: set[Instruments] | None = None,
     block_instruments: set[Instruments] | None = None,
-    client: LaminarClient | None = None,
     async_client: AsyncLaminarClient | None = None,
 ):
     block_instruments = block_instruments or set()
@@ -124,7 +125,7 @@ def init_instrumentations(
             continue
 
         try:
-            instrumentor = initializer.init_instrumentor(client, async_client)
+            instrumentor = initializer.init_instrumentor(async_client)
             if instrumentor is None:
                 continue
             if not instrumentor.is_instrumented_by_opentelemetry:
